@@ -8,7 +8,24 @@
 #include <errno.h>
 #include <strings.h>
 
+static char rcsid[] ="$Id: scsidev.c,v 1.2 1997/03/29 15:45:50 eric Exp $";
+
+#include "config.h"
+
+#ifdef HAVE_SCSI_SCSI_H					/* { */
+#include <scsi/scsi.h>
+#else							/* } { */
+#ifdef HAVE_LINUX_SCSI_H				/* { */
 #include <linux/scsi.h>
+#else							/* } { */
+#ifdef HAVE__USR_SRC_LINUX_DRIVERS_SCSI_SCSI_H 		/* { */
+#include "/usr/src/linux/drivers/scsi/scsi.h"
+#else							/* } { */
+#error "Unable to include scsi.h"
+#endif							/* } */
+#endif							/* } */
+#endif							/* } */
+
 #include <getopt.h>
 
 int use_symlink = 0;
